==> frma_1.0.0.tar.gz: frma/man/frma.Rd <==
\name{frma}
\alias{frma}
\title{Frozen Robust Multi-Array Analysis}
\description{
  This function preprocesses an AffyBatch object using the fRMA method.
}
\usage{
frma(object, background="rma", normalize="quantile",
    summarize="robust_weighted_average", input.vecs=list(normVec=NULL,
    probeVec=NULL, probeVarBetween=NULL, probeVarWithin=NULL,
    probesetSD=NULL), output.param=NULL, verbose=FALSE) 
}
\arguments{
  \item{object}{an AffyBatch}
  \item{background}{type of background correction to perform: either
    "none" or "rma".}
  \item{normalize}{type of normalization to perform: either "none" or
    "quantile".}  
  \item{summarize}{type of summarization to perform: one of
    "median\_polish", "average", "median", "weighted\_average",
    "robust\_weighted\_average", "batch".}
  \item{input.vecs}{a list of vectors to be used in preprocessing. If
    necessary elements are NULL, the correct package with the default
    vectors is loaded if it has been installed. These packages are of
    the form: <platform>frmavecs.}
  \item{output.param}{a vector of output elements to return. By default
    only the expression values are returned. Can contain any of
    "residuals", "weights", or "stderr"}
  \item{verbose}{logical value. If TRUE then some messages are displayed
    while the function runs.}
}
\value{
  The function returns either an ExpressionSet or a frmaExpressionSet
  object depending on the elements of output.param. The assayData field
  of these objects contains the expression values (exprs) and optionally
  the standard errors (se.exprs). A frmaExpressionSet contains two
  further optional fields: the weights used in the summarization step
  (weights) and the residuals from fitting the probe-level model (residuals).
}
\author{Matthew N. McCall}
\examples{
  library(frmaExampleData)
  data(AffyBatchExample)
  object <- frma(AffyBatchExample)
}
\keyword{manip}

==> frma_1.2.0.tar.gz: frma/man/frma.Rd <==
\name{frma}
\alias{frma}
\title{Frozen Robust Multi-Array Analysis}
\description{
  This function preprocesses an AffyBatch object using the fRMA method.
}
\usage{
frma(object, background="rma", normalize="quantile",
    summarize="robust_weighted_average", input.vecs=list(normVec=NULL,
    probeVec=NULL, probeVarBetween=NULL, probeVarWithin=NULL,
    probesetSD=NULL), output.param=NULL, verbose=FALSE) 
}
\arguments{
  \item{object}{an AffyBatch}
  \item{background}{type of background correction to perform: either
    "none" or "rma".}
  \item{normalize}{type of normalization to perform: either "none" or
    "quantile".}  
  \item{summarize}{type of summarization to perform: one of
    "median\_polish", "average", "median", "weighted\_average",
    "robust\_weighted\_average", "batch".}
  \item{input.vecs}{a list of vectors to be used in preprocessing. If
    necessary elements are NULL, the correct package with the default
    vectors is loaded if it has been installed. These packages are of
    the form: <platform>frmavecs.}
  \item{output.param}{a vector of output elements to return. By default
    only the expression values are returned. Can contain any of
    "residuals", "weights", or "stderr"}
  \item{verbose}{logical value. If TRUE then some messages are displayed
    while the function runs.}
}
\value{
  The function returns a PLMset.
}
\author{Matthew N. McCall}
\examples{
  library(frmaExampleData)
  data(AffyBatchExample)
  object <- frma(AffyBatchExample)
}
\keyword{manip}
